package com.jay.monitor.data.server.componts.cache;

import com.google.common.collect.Maps;

import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * 分组纬度缓存，二级缓存
 * <p>
 * 一级缓存负责存储源数据,和id绑定
 * 二级缓存负责存储其他字段,绑定id
 *
 * @author liukaixiong
 * @date 2022/7/26 - 10:14
 */
public abstract class AbstractGroupLocalCacheProcess<T> extends AbstractLocalCacheProcess<T>
    implements IGroupLocalCacheService<T> {

    private Map<String, Set<String>> groupIdCache = new HashMap<>();

    /**
     * 组缓存的key
     *
     * @return
     */
    public abstract Function<T, String> cacheGroupKey();

    @Override
    public void refreshGroup(String group) {
        Set<String> groupList = groupIdCache.get(getGroupKey(group));
        groupList.forEach(this::refreshId);
    }

    private String getGroupKey(T groupObject) {
        return cacheGroupKey().apply(groupObject);
    }

    protected String getGroupKey(String group) {
        return group;
    }

    @Override
    public void removeGroup(String group) {
        Set<String> groupList = groupIdCache.get(getGroupKey(group));
        // 删除一级缓存中的数据
        groupList.forEach(this::removeId);
        // 删除二级缓存中的数据
        groupIdCache.remove(group);
    }

    @Override
    public List<T> getList(String group) {
        Set<String> groupList = groupIdCache.getOrDefault(getGroupKey(group), new HashSet<>());
        return groupList.stream().map(this::get).collect(Collectors.toList());
    }

    @Override
    public void refreshAll() {

        // 重构父类缓存,一级缓存
        super.refreshAll();

        // 重构二级缓存
        Map<String, Set<String>> refreshCache = Maps.newHashMap();
        getObjectCache().values().forEach(var -> {
            String groupKey = getGroupKey(var);
            Set<String> ids = refreshCache.computeIfAbsent(groupKey, val -> new HashSet<>());
            String id = getIdKey(var);
            ids.add(id);
        });

        this.groupIdCache = refreshCache;

    }

}
