package com.jay.monitor.data.server.componts.cache;

import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;

/**
 * 抽象本地缓存，负责根据id存储源数据
 *
 * @author liukaixiong
 * @date 2022/7/25 - 17:17
 */
public abstract class AbstractLocalCacheProcess<T> implements IIdLocalCacheService<T> {
    private final Logger logger = LoggerFactory.getLogger(getClass());

    private Map<String, T> objectCache = new HashMap<>();

    /**
     * 根据主键获取数据
     *
     * @param id
     * @return
     */
    public abstract T getData(String id);

    /**
     * 缓存的key
     *
     * @return
     */
    protected abstract Function<T, String> cacheIdKey();

    /**
     * 获取所有数据
     *
     * @return
     */
    public abstract List<T> getAll();

    @Override
    public void refreshAll() {
        List<T> all = getAll();

        if (CollectionUtils.isEmpty(all)) {
            return;
        }

        if (all.size() > 1000) {
            logger.warn(" 本地缓存数量达到 :{}", all.size());
        }

        Map<String, T> refreshCache = new HashMap<>();

        all.forEach(var -> {
            String id = getIdKey(var);
            refreshCache.put(id, var);
        });
        this.objectCache = refreshCache;
        logger.debug(" 缓存类:{} 重新加载完毕!", getClass().getName());
    }

    protected String getIdKey(T var) {
        Function<T, String> key = cacheIdKey();
        return key.apply(var);
    }

    @Override
    public void refreshId(String id) {
        objectCache.put(id, this.getData(id));
    }

    @Override
    public void removeId(String id) {
        objectCache.remove(id);
    }

    @Override
    public T get(String id) {
        return objectCache.computeIfAbsent(id, this::getData);
    }

    protected void refreshCache(String key, T value) {
        this.objectCache.put(key, value);
    }

    protected Map<String, T> getObjectCache() {
        return objectCache;
    }

}
