package com.jay.monitor.data.server.config.props;

import com.jay.monitor.data.core.enums.MonitorDataConstants;
import com.jay.monitor.data.server.enums.DataSplitType;
import com.jay.monitor.data.server.enums.StoreType;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.NestedConfigurationProperty;

import java.util.HashMap;
import java.util.Map;

/**
 * @Module 配置
 * @Description 监控服务器配置属性
 * @Author liukaixiong
 * @Date 2020/11/5 13:52
 */
@ConfigurationProperties(prefix = "spring.monitor-server")
public class MonitorProperties {

    private Integer transferPort = MonitorDataConstants.DEFAULT_PORT;

    /**
     * 是否启用环境前缀作为存储前缀
     */
    private boolean enableEnvPrefix = false;

    /**
     * 数据存储天数
     */
    private Integer saveHistoryDay = 30;

    /**
     * 存储类型
     */
    private StoreType storeType;
    /**
     * 存储配置规则
     * key -> {@link com.jay.monitor.data.server.enums.StoreType}
     */
    private Map<StoreType, StoreInfo> storeInfo = new HashMap<>();

    @NestedConfigurationProperty
    private JayServerProperties server = new JayServerProperties();
    @NestedConfigurationProperty
    private AlertProperties alert;

    public AlertProperties getAlert() {
        return alert;
    }

    public void setAlert(AlertProperties alert) {
        this.alert = alert;
    }

    public Integer getSaveHistoryDay() {
        return saveHistoryDay;
    }

    public void setSaveHistoryDay(Integer saveHistoryDay) {
        this.saveHistoryDay = saveHistoryDay;
    }

    public JayServerProperties getServer() {
        return server;
    }

    public void setServer(JayServerProperties server) {
        this.server = server;
    }

    public Map<StoreType, StoreInfo> getStoreInfo() {
        return storeInfo;
    }

    public void setStoreInfo(Map<StoreType, StoreInfo> storeInfo) {
        this.storeInfo = storeInfo;
    }

    public StoreType getStoreType() {
        return storeType;
    }

    public void setStoreType(StoreType storeType) {
        this.storeType = storeType;
    }

    public Integer getTransferPort() {
        return transferPort;
    }

    public void setTransferPort(Integer transferPort) {
        this.transferPort = transferPort;
    }

    public boolean isEnableEnvPrefix() {
        return enableEnvPrefix;
    }

    public void setEnableEnvPrefix(boolean enableEnvPrefix) {
        this.enableEnvPrefix = enableEnvPrefix;
    }

    public static class StoreInfo {

        /**
         * 表的拆分配置规则
         * Key -> 表名
         */
        private Map<String, DataSplitType> tableRule = new HashMap<>();

        public Map<String, DataSplitType> getTableRule() {
            return tableRule;
        }

        public void setTableRule(Map<String, DataSplitType> tableRule) {
            this.tableRule = tableRule;
        }
    }

}
