package com.jay.monitor.data.server.controllers;//package com.jay.monitor.data.server.controllers;

import com.jay.monitor.data.core.model.response.PageResponseModel;
import com.jay.monitor.data.core.utils.JsonHelper;
import com.jay.monitor.data.core.utils.ResponseUtils;
import com.jay.monitor.data.server.componts.html.DefaultDataRender;
import com.jay.monitor.data.server.controllers.crud.BaseSimpleCrudController;
import com.jay.monitor.data.server.enums.GlobalConfigGroupEnums;
import com.jay.monitor.data.server.models.request.global.GlobalBaseConfigRequest;
import com.jay.monitor.data.server.models.store.GlobalBaseConfig;
import com.jay.monitor.data.server.services.impl.GlobalConfigServiceCache;
import com.jay.monitor.data.server.services.IGlobalBaseConfigProcess;
import com.jay.monitor.data.server.store.ISimpleCrudProcess;
import com.jay.monitor.data.server.utils.HtmlComponentUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import java.util.List;

import static com.jay.monitor.data.server.controllers.GlobalBaseConfigController.PREFIX_URL;

/**
 * 全局基础配置管理
 *
 * @author liukx
 * @Date 2019-02-28 15:16
 */
@Controller
@RequestMapping(value = PREFIX_URL)
public class GlobalBaseConfigController extends BaseSimpleCrudController<GlobalBaseConfigRequest, GlobalBaseConfig> {

    public final static String PREFIX_URL = "/global/base/config";
    public final static String LIST_URL = PREFIX_URL + "/pageList";
    public final static String ADD_URL = PREFIX_URL + "/add";
    public final static String UPDATE_URL = PREFIX_URL + "/update";
    public final static String DEL_URL = PREFIX_URL + "/del";
    public static final String PAGE_PATH = "/global";

    @Override
    public String getViewPath() {
        return PAGE_PATH;
    }

    @Autowired
    private IGlobalBaseConfigProcess configProcess;

    @Autowired
    private GlobalConfigServiceCache globalConfigServiceCache;

    @Override
    public ISimpleCrudProcess getCrudProcess() {
        return configProcess;
    }

    @Override
    protected String getAddHtmlPath() {
        return "/update";
    }

    @Override
    @RequestMapping(value = "/pageList",
        method = RequestMethod.POST,
        produces = "application/json;charset=UTF-8")
    @ResponseBody
    public PageResponseModel<GlobalBaseConfig> pageList(
        @RequestBody
            GlobalBaseConfigRequest request) throws Exception {
        GlobalBaseConfig config = new GlobalBaseConfig();
        BeanUtils.copyProperties(request, config);
        // 将参数对应的全部匹配赋值
        PageResponseModel pageResponseModel =
            configProcess.searchDataByList(request.getPageNo(), request.getPageSize(), config);
        GlobalBaseConfig searchGroup = new GlobalBaseConfig();
        searchGroup.setStatus(1);
        return pageResponseModel;
    }

    @Override
    protected void addBefore(GlobalBaseConfig req) {
        checkExpression(req);
    }

    @Override
    protected void addAfter(GlobalBaseConfig req, boolean result) {
        refreshPlatformId(req.getId());
    }

    @Override
    protected void addInModel(Model model, GlobalBaseConfig entity) {
        model.addAttribute("apiService", ADD_URL);
        GlobalBaseConfig globalBaseConfig = new GlobalBaseConfig();
        globalBaseConfig.setStatus(1);
        model.addAttribute("obj", globalBaseConfig);
        modelAfter(model, globalBaseConfig);
    }

    @Override
    protected void updateInModel(Model model, GlobalBaseConfig entity) {
        model.addAttribute("apiService", UPDATE_URL);
        super.updateInModel(model, entity);
    }

    @Override
    protected void updateBefore(GlobalBaseConfig req) {
        ResponseUtils.checkNull(req.getId(), "id不能为空!");
    }

    @Override
    protected void updateAfter(GlobalBaseConfig req, boolean result) {
        refreshPlatformId(req.getId());
    }

    public void refreshPlatformId(String id) {
        globalConfigServiceCache.refreshId(id);
    }

    @Override
    protected void deleteAfter(GlobalBaseConfig req, boolean result) {
        globalConfigServiceCache.removeId(req.getId());
    }

    @Override
    protected void modelAfter(Model model, GlobalBaseConfig entity) {
        List<DefaultDataRender> defaultDataRenders = HtmlComponentUtils
            .convertDataRender(GlobalConfigGroupEnums.class, var -> String.format("[%s]:%s", var.getCode(), var.getLabel()));
        model.addAttribute("defaultDataRenders", JsonHelper.toJsonString(defaultDataRenders));
    }

    private void checkExpression(GlobalBaseConfig req) {
        ResponseUtils.checkNull(req.getGroup(), "group不能为空!");
        ResponseUtils.checkNull(req.getProject(), "project不能为空!");
        ResponseUtils.checkNull(req.getCode(), "code不能为空!");
        ResponseUtils.checkNull(req.getValue(), "value不能为空!");
    }
}
