package com.jay.monitor.data.server.controllers;

import com.google.common.collect.Sets;
import com.jay.monitor.data.core.enums.MsgTypeEnums;
import com.jay.monitor.data.core.model.response.ResponseCommonModel;
import com.jay.monitor.data.core.model.serializable.ServiceDataDTO;
import com.jay.monitor.data.core.utils.JsonHelper;
import com.jay.monitor.data.core.utils.ResponseUtils;
import com.jay.monitor.data.server.store.StoreDataManager;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.Map;
import java.util.Set;

/**
 * 指标收集
 *
 * @author liukaixiong
 * @date 2022/7/25 - 15:59
 */
@Controller
@RequestMapping(value = "/metric")
public class MetricCollectController {
    private Logger logger = LoggerFactory.getLogger(getClass());
    private Set<String> subscriptType = Sets.newHashSet("Business", "Transaction", "Event", "Heartbeat");
    @Autowired
    private StoreDataManager storeDataManager;

    @RequestMapping(value = "/push",
        method = RequestMethod.POST,
        produces = "application/json;charset=UTF-8")
    @ResponseBody
    public ResponseCommonModel push(
        @RequestBody
            ServiceDataDTO request) throws Exception {
        storeDataManager.store(MsgTypeEnums.SERVICE, request);
        return ResponseUtils.trueObj(null);
    }

    @RequestMapping(value = "/cat",
        method = RequestMethod.POST)
    @ResponseBody
    public ResponseCommonModel catPush(
        @RequestParam
            Map<String, Object> cat) throws Exception {
        Object type = cat.get("type");
        Object secretKey = cat.get("secretKey");

        if (secretKey == null) {
            return ResponseUtils.trueObj("找不到密钥!");
        }

        if (type == null || !subscriptType.contains(type.toString())) {
            return ResponseUtils.trueObj(null);
        }

        ServiceDataDTO serviceDataDTO = new ServiceDataDTO();
        serviceDataDTO.setStatus(1);
        serviceDataDTO.setApplicationName(cat.getOrDefault("domain", "cat").toString());
        serviceDataDTO.setRequestTime(-1L);
        serviceDataDTO.setIp(cat.getOrDefault("ip", "127.0.0.1").toString());
        serviceDataDTO.setJsonContent(JsonHelper.toJsonString(cat));
        serviceDataDTO.setCreateDate(new Date());
        serviceDataDTO.setMethodName(type.toString());
        serviceDataDTO.setGroupName(type.toString());
        // weixin : {"domain":"cat","email":"888888888","title":"[CAT异常告警] [项目: cat]","content":"[CAT异常告警] [项目: cat] : [ 异常名称: Total 异常数量：2.0 ][时间: 2022-07-25 16:51] \r\n\n\r\n\n\n\r\n\n[告警间隔时间]5分钟","type":"Exception","alert":"weixin"}
        // sms : {"jsonm":"{type:808,mobile:'12345678901,12345678902',pair:{body='[CAT异常告警] [项目: cat] [CAT异常告警] [项目: cat] : [ 异常名称: Total 异常数量：2.0 ][时间: 2022-07-25 16:51] \r \r  \r [告警间隔时间]5分钟'}}","alert":"sms"}
        // todo 暂无实现,感觉也提取不了什么有效的
        logger.info("cat : {}", JsonHelper.toJsonString(cat));
        return ResponseUtils.trueObj(null);
    }
}
