package com.jay.monitor.data.server.store;

import com.jay.monitor.data.core.enums.MsgTypeEnums;
import com.jay.monitor.data.server.config.props.AlertProperties;
import com.jay.monitor.data.server.enums.AlertMsgEnums;
import com.jay.monitor.data.server.enums.GlobalConfigCodeEnums;
import com.jay.monitor.data.server.enums.GlobalConfigGroupEnums;
import com.jay.monitor.data.server.models.config.AlertConfigModel;
import com.jay.monitor.data.server.models.config.AlertRuleConfigModel;
import com.jay.monitor.data.server.models.store.GlobalBaseConfig;
import com.jay.monitor.data.server.services.impl.GlobalConfigServiceCache;
import com.jay.monitor.data.server.utils.DataUtils;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @Module 配置模块
 * @Description 基于本地文件配置
 * @Author liukaixiong
 * @Date 2021/1/15 10:55
 */
public class DefaultLocalConfigManager implements ConfigStoreManager {

    @Autowired
    private AlertProperties alertProperties;

    @Autowired
    private GlobalConfigServiceCache globalConfigServiceCache;

    @Override
    public String getConsoleUrl() {
        return getCacheValue(GlobalConfigGroupEnums.GLOBAL_CONFIG_PROPS, GlobalConfigCodeEnums.SERVER_DOMAIN.name(),
            alertProperties.getConsoleUrl());
    }

    @Override
    public String getLogMonitorUrl() {
        return getCacheValue(GlobalConfigGroupEnums.GLOBAL_CONFIG_PROPS, GlobalConfigCodeEnums.LOG_MONITOR_URL.name(),
            alertProperties.getLogMonitorUrl());
    }

    @Override
    @Deprecated
    public String getServerLogConsole() {
        return alertProperties.getServerLogConsole();
    }

    @Override
    public boolean alertEnable() {
        return getCacheValue(GlobalConfigGroupEnums.GLOBAL_CONFIG_PROPS, GlobalConfigCodeEnums.ALERT_ENABLE.name(),
            alertProperties.isEnable());
    }

    @Override
    @Deprecated
    public AlertConfigModel getAlertConfigModel(AlertMsgEnums alertMsgEnums) {
        Map<AlertMsgEnums, AlertConfigModel> alertType = alertProperties.getAlertType();
        return alertType.get(alertMsgEnums);
    }

    @Override
    public Long getAlertIntervalMinutes() {
        return getCacheValue(GlobalConfigGroupEnums.GLOBAL_CONFIG_PROPS,
            GlobalConfigCodeEnums.ALERT_INTERVAL_MINUTES_ENABLE.name(), alertProperties.getAlertIntervalMinutes());
    }

    @Override
    public AlertRuleConfigModel getAlertRuleConfigModel(MsgTypeEnums msgTypeEnums) {
        Map<MsgTypeEnums, AlertRuleConfigModel> alertRuleConfigMap = alertProperties.getAlertRuleConfigMap();
        return alertRuleConfigMap.get(msgTypeEnums);
    }

    private <T> T getCacheValue(GlobalConfigGroupEnums globalConfigGroupEnums, String code, T defaultValue) {
        try {
            List<GlobalBaseConfig> groupValue = globalConfigServiceCache.getList(globalConfigGroupEnums.name());
            if (CollectionUtils.isNotEmpty(groupValue)) {
                Map<String, String> groupMap = groupValue.stream()
                    .collect(Collectors.toMap(GlobalBaseConfig::getCode, GlobalBaseConfig::getValue));
                String value = groupMap.get(code);
                return DataUtils.getStringDefaultValue(value, defaultValue);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return defaultValue;
    }

    @Override
    public Integer getSaveHistoryDay() {
        return null;
    }
}
