package com.jay.monitor.data.server.utils;

import cn.hutool.extra.spring.SpringUtil;
import com.jay.monitor.data.server.config.props.JayServerProperties;
import com.jay.monitor.data.server.config.props.MonitorProperties;
import com.jay.monitor.data.server.enums.DataSplitType;
import com.jay.monitor.data.server.enums.StoreType;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Map;

/**
 * @Module 工具类
 * @Description 规范化监控属性获取
 * @Author liukaixiong
 * @Date 2020/11/5 20:02
 */
public class MonitorEnvHelper {
    private final static Logger LOGGER = LoggerFactory.getLogger(MonitorEnvHelper.class);

    public static boolean enableEnvPrefix() {
        return getMonitor().isEnableEnvPrefix();
    }

    public static Integer saveHistoryDay() {
        return getMonitor().getSaveHistoryDay();
    }

    private static MonitorProperties getMonitor() {
        try {
            return SpringUtil.getBean(MonitorProperties.class);
        } catch (Exception e) {
            LOGGER.error("获取配置异常", e);
            return new MonitorProperties();
        }
    }

    public static Map<String, DataSplitType> getMysqlTableRuleMap() {
        return getTableRuleMap(getMonitor().getStoreType());
    }

    public static String getEnvPrefixName(String name) {
        if (enableEnvPrefix()) {
            return SpringUtil.getActiveProfile() + "_" + name;
        }
        return name;
    }

    public static JayServerProperties getServerProperties() {
        return getMonitor().getServer();
    }

    public static Map<String, DataSplitType> getTableRuleMap(StoreType storeType) {
        MonitorProperties properties = getMonitor();
        Map<StoreType, MonitorProperties.StoreInfo> storeInfoMap = properties.getStoreInfo();

        if (properties.getStoreInfo() == null) {
            return null;
        }

        MonitorProperties.StoreInfo storeInfo = storeInfoMap.get(storeType);

        if (storeInfo == null) {
            return null;
        }

        return storeInfo.getTableRule();
    }
}
